==> mingw-w64-clang-aarch64-python-contourpy-1.3.0-1-any.pkg.tar.zst: clangarm64/lib/python3.11/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.11",
        python_install_dir=r"C:/msys64/clangarm64/lib/python3.11/site-packages/",
        python_path=r"C:/msys64/clangarm64/bin/python.exe",

        # Package versions
        contourpy_version="1.3.0",
        meson_version="1.5.1",
        mesonpy_version="0.16.0",
        pybind11_version="2.13.5",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"C:/M/B/src/python-build-CLANGARM64/.mesonpy-v8p7s2xn/lib/contourpy/util",
        source_dir=r"C:/M/B/src/python-build-CLANGARM64/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-CLANGARM64/.mesonpy-v8p7s2xn/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="False",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="clang",
        compiler_version="18.1.8",
        linker_id="ld.lld",
        compile_command="clang++",

        # Host machine
        host_cpu="aarch64",
        host_cpu_family="aarch64",
        host_cpu_endian="little",
        host_cpu_system="windows",

        # Build machine, same as host machine if not a cross_build
        build_cpu="aarch64",
        build_cpu_family="aarch64",
        build_cpu_endian="little",
        build_cpu_system="windows",
    )

==> mingw-w64-clang-aarch64-python-contourpy-1.3.1-1-any.pkg.tar.zst: clangarm64/lib/python3.12/site-packages/contourpy/util/_build_config.py <==
# _build_config.py.in is converted into _build_config.py during the meson build process.

from __future__ import annotations


def build_config() -> dict[str, str]:
    """
    Return a dictionary containing build configuration settings.

    All dictionary keys and values are strings, for example ``False`` is
    returned as ``"False"``.

        .. versionadded:: 1.1.0
    """
    return dict(
        # Python settings
        python_version="3.12",
        python_install_dir=r"C:/msys64/clangarm64/lib/python3.12/site-packages/",
        python_path=r"C:/msys64/clangarm64/bin/python.exe",

        # Package versions
        contourpy_version="1.3.1",
        meson_version="1.6.1",
        mesonpy_version="0.17.1",
        pybind11_version="2.13.6",

        # Misc meson settings
        meson_backend="ninja",
        build_dir=r"C:/M/B/src/python-build-CLANGARM64/.mesonpy-q_i4_qjt/lib/contourpy/util",
        source_dir=r"C:/M/B/src/python-build-CLANGARM64/lib/contourpy/util",
        cross_build="False",

        # Build options
        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md --native-file=C:/M/B/src/python-build-CLANGARM64/.mesonpy-q_i4_qjt/meson-python-native-file.ini",
        buildtype="release",
        cpp_std="c++17",
        debug="False",
        optimization="3",
        vsenv="False",
        b_ndebug="if-release",
        b_vscrt="from_buildtype",

        # C++ compiler
        compiler_name="clang",
        compiler_version="19.1.6",
        linker_id="ld.lld",
        compile_command="clang++",

        # Host machine
        host_cpu="aarch64",
        host_cpu_family="aarch64",
        host_cpu_endian="little",
        host_cpu_system="windows",

        # Build machine, same as host machine if not a cross_build
        build_cpu="aarch64",
        build_cpu_family="aarch64",
        build_cpu_endian="little",
        build_cpu_system="windows",
    )
